Learn R Programming

AHM (version 1.0.1)

pringles_candidates2search: The candidate search points in the nonlinear optimization for the optimal value in the Pringles experiment

Description

The candidate search points in the nonlinear optimization for the optimal value in the Pringles experiment

Usage

data(pringles_candidates2search)

Arguments

Format

matrix

Examples

Run this code
# NOT RUN {
data(pringles_candidates2search)
# }
# NOT RUN {
print(pringles_candidates2search)
# }

Run the code above in your browser using DataLab