Learn R Programming

AHM (version 1.0.1)

pringles_fat: Pringles experiment data set with the percent of Fat as the response

Description

Pringles experiment data set with the percent of Fat as the response

Usage

data(pringles_fat)

Arguments

Format

data.frame

References

Kang, L., Joseph, V.R. and Brenneman, W.A. (2011). Design and modeling strategies for mixture-of-mixtures experiments. Technometrics, 53(2), 125--36. (tandfonline)

Examples

Run this code
# NOT RUN {
data(pringles_fat)
# }
# NOT RUN {
print(pringles_fat)
# }

Run the code above in your browser using DataLab